@@ -29,5 +29,6 @@ export default {
   "Unselect": "Deseleziona",
   "Configure layer": "Configura layer",
   "Properties: [{0}] {1}": "Proprietà: [{0}] {1}",
-  "Get Screenshot" : "Cattura uno screenshot"
+  "Get Screenshot" : "Cattura uno screenshot",
+  "Catalog" : "Catalogo"
 }
